==> qbankmanager_0.9.29.orig.tar.gz: qbankmanager-0.9.29/src/kbanking/libs/dialogs/rulenameedit.cpp <==
/***************************************************************************
 $RCSfile: rulenameedit.cpp,v $
                             -------------------
    cvs         : $Id: rulenameedit.cpp,v 1.1 2004/11/21 09:36:38 aquamaniac Exp $
    begin       : Mon Mar 01 2004
    copyright   : (C) 2004 by Martin Preuss
    email       : martin@libchipcard.de

 ***************************************************************************
 *          Please see toplevel file COPYING for license details           *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
# include <config.h>
#endif


#include "rulenameedit.h"

#include <qwidget.h>
#include <qstring.h>
#include <qlabel.h>
#include <qlineedit.h>
#include <qpushbutton.h>

#include <gwenhywfar/debug.h>






RuleNameEdit::RuleNameEdit(const QString &title,
                           const char *name,
                           const char *shortDescr,
                           QWidget* parent,
                           const char *wname,
                           bool modal,
                           WFlags fl)
:RuleNameEditUI(parent, wname, modal, fl) {
  if (!title.isEmpty())
    setCaption(title);
  if (name)
    nameEdit->setText(QString::fromUtf8(name));
  if (shortDescr)
    shortEdit->setText(QString::fromUtf8(name));

  QObject::connect((QObject*)nameEdit, SIGNAL(textChanged(const QString &)),
                   this, SLOT(slotNameChanged(const QString &)));

}



RuleNameEdit::~RuleNameEdit(){
}



QString RuleNameEdit::getName(){
  return nameEdit->text();
}



QString RuleNameEdit::getShortDescription(){
  return shortEdit->text();
}



void RuleNameEdit::slotNameChanged(const QString &qs) {
  okButton->setEnabled(!qs.isEmpty());
}

==> qbankmanager_0.9.37.orig.tar.gz: qbankmanager-0.9.37/src/kbanking/libs/dialogs/rulenameedit.cpp <==
/***************************************************************************
 $RCSfile: rulenameedit.cpp,v $
                             -------------------
    cvs         : $Id: rulenameedit.cpp,v 1.2 2005/10/02 14:05:27 cstim Exp $
    begin       : Mon Mar 01 2004
    copyright   : (C) 2004 by Martin Preuss
    email       : martin@libchipcard.de

 ***************************************************************************
 *          Please see toplevel file COPYING for license details           *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
# include <config.h>
#endif


#include "rulenameedit.h"

#include <qwidget.h>
#include <qstring.h>
#include <qlabel.h>
#include <qlineedit.h>
#include <qpushbutton.h>

#include <gwenhywfar/debug.h>






RuleNameEdit::RuleNameEdit(const QString &title,
                           const char *name,
                           const char *shortDescr,
                           QWidget* parent,
                           const char *wname,
                           bool modal,
                           WFlags fl)
:RuleNameEditUI(parent, wname, modal, fl) {
  if (!title.isEmpty())
    setCaption(title);
  if (name)
    nameEdit->setText(QString::fromUtf8(name));
  if (shortDescr)
    shortEdit->setText(QString::fromUtf8(name));

  QObject::connect(nameEdit, SIGNAL(textChanged(const QString &)),
                   this, SLOT(slotNameChanged(const QString &)));

}



RuleNameEdit::~RuleNameEdit(){
}



QString RuleNameEdit::getName(){
  return nameEdit->text();
}



QString RuleNameEdit::getShortDescription(){
  return shortEdit->text();
}



void RuleNameEdit::slotNameChanged(const QString &qs) {
  okButton->setEnabled(!qs.isEmpty());
}
